package PVS.HyperProf;
//
// Copyright (C) 1996 by Vladimir Bulatov <V.Bulatov@ic.ac.uk>.  
//        All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
// OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
// SUCH DAMAGE.

import java.util.Hashtable;
import java.util.Enumeration;

import PVS.Utils.Comparator;

class PackageEntry extends Object implements Comparator {

  String name;

  Hashtable classes = new Hashtable();
  
  PackageEntry(String name){
    this.name = name;    
  }
  
  private boolean isModified = false;

  void addClass(ProfEntry entry){
    ClassEntry ce = (ClassEntry)classes.get(entry.name.className);
    if(ce == null){
      ce = new ClassEntry(entry.name.className);
      classes.put(entry.name.className,ce);
    }
    isModified = true;
    ce.addMethod(entry);
  }
  
  int countMethods(){
    int n = 0;
    for(Enumeration cle = classes.elements(); cle.hasMoreElements();){
      n += ((ClassEntry)cle.nextElement()).methods.size();
    }
    return n;
  }

  // time spent in methods of this class in millisecond
  private int total_time=0;

  int getTotalTime(){
    if(isModified){
      total_time = 0;
      for(Enumeration cle = classes.elements(); cle.hasMoreElements();){
	total_time += ((ClassEntry)cle.nextElement()).getTotalTime();
      }
    }
    isModified = false;
    return total_time;;
  }

  public int compare(Object fst, Object snd){
    return  
      ((PackageEntry)snd).getTotalTime() - ((PackageEntry)fst).getTotalTime();
  }
 
}


